@extends('algo::layouts.app', [
    'meta_title' => trans("algo::algo.posts.edit.title")
])

@section('content')
<div class="container">
    <div class="row justify-content-center">
        <div class="col-md-8">
            <div class="card">
                <div class="card-header">@lang("algo::algo.posts.edit.header")

                    @languageSwitcher([
                        'model_id' => $post->id,
                        'resource_route_name' => 'posts'
                    ])

                </div>

                <div class="card-body">
                    @statusAlert

                    {{-- @include('admin.ui.bootstrap4.forms.tmp_errors') --}}

                    @form([
                        'action' =>route('algo.posts.update', $post->id),
                        'method' => 'PUT'
                    ])
                        @input([
                            'name' => 'title',
                            'label' => trans('algo::algo.label_name'),
                            'placeholder' => trans('algo::algo.placeholder_name'),
                            'value' => $post->title,
                            'required' => true
                        ])

                        @input([
                            'name' => 'slug',
                            'label' => trans('algo::algo.label_slug'),
                            'placeholder' => trans('algo::algo.placeholder_slug'),
                            'help' => trans('algo::algo.leave_field_empty'),
                            'value' => $post->slug
                        ])

                        @input([
                            'name' => 'intro',
                            'label' => trans('algo::algo.label_intro'),
                            'placeholder' => trans('algo::algo.placeholder_intro')
                        ])

                        @textarea([
                            'name' => 'content',
                            'label' => trans('algo::algo.label_content'),
                            'help' => trans('algo::algo.use_markdown_syntax'),
                            'rows' => 7,
                            'value' => $post->content,
                            'required' => true
                        ])

                        @input([
                            'name' => 'video_link',
                            'label' => 'YouTube video link',
                            'placeholder' => 'https://',
                            'value' => $post->video_link
                        ])

                        @input([
                            'name' => 'published_at_date',
                            'label' => trans('algo::algo.label_published_at_date'),
                            'type' => 'date',
                            'value' => is_null($post->published_at) ? '' : $post->published_at->format('Y-m-d')
                        ])

                        @input([
                            'name' => 'published_at_time',
                            'label' => trans('algo::algo.label_published_at_time'),
                            'type' => 'time',
                            'value' => is_null($post->published_at) ? '' : $post->published_at->format('H:i')
                        ])

                        @select([
                            'label' => trans('algo::algo.label_author'),
                            'name' => 'author_id',
                            'options' => $authors,
                            'placeholder' => trans('algo::algo.placeholder_author'),
                            'selected' => $post->author->id,
                            'required' => true
                        ])

                        @select([
                            'label' => trans('algo::algo.label_category'),
                            'name' => 'category_id',
                            'options' => $categories,
                            'placeholder' => trans('algo::algo.placeholder_category'),
                            'selected' => $post->category->id,
                            'required' => true
                        ])

                        @select([
                            'label' => trans('algo::algo.label_tags'),
                            'name' => 'tags_list[]',
                            'options' => $tags,
                            'placeholder' => trans('algo::algo.placeholder_tags'),
                            'multiple' => true,
                            'selected' => $post->tags->pluck('id')->toArray()
                        ])

                        @checkbox([
                            'label' => trans('algo::algo.label_featured'),
                            'name' => 'featured',
                            'checked' => $post->featured
                        ])

                        @submit(['text' => trans('algo::algo.edit')])
                        <a class="btn btn-link" href="{{ route('algo.posts.show', $post->id) }}">{{ trans('algo::algo.cancel') }}</a>
                    @endform
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
