@extends('algo::layouts.app', [
    'meta_title' => trans("algo::algo.posts.show.title")
])

@section('content')
<div class="container">
    <div class="row justify-content-center">
        <div class="col-md-8">
            <div class="card">
                <div class="card-header">
                    @lang("algo::algo.posts.show.header")

                    @tablist

                </div>

                <div class="card-body">
                    @statusAlert

                    <div class="tab-content">
                        @foreach(config('translatable.locales') as $supported_locale)
                            @tabpanel(['locale' => $supported_locale])

                                @field([
                                    'label' => trans('algo::algo.label_name', [], $supported_locale),
                                    // 'locale' => $supported_locale,
                                    'value' => $post->translateOrDefault($supported_locale)->title
                                ])

                                @field([
                                    'label' => trans('algo::algo.label_slug', [], $supported_locale),
                                    // 'locale' => $supported_locale,
                                    'value' => $post->translateOrDefault($supported_locale)->slug
                                ])

                                @if (!empty($post->intro))
                                    @field([
                                        'label' => trans('algo::algo.label_intro', [], $supported_locale),
                                        // 'locale' => $supported_locale,
                                        'value' => $post->translateOrDefault($supported_locale)->intro
                                    ])
                                @endif

                                @field([
                                    'label' => trans('algo::algo.label_content', [], $supported_locale),
                                    // 'locale' => $supported_locale,
                                    'value' => $post->translateOrDefault($supported_locale)->content,
                                    'markdown' => true
                                ])

                                @field([
                                    'label' => trans('algo::algo.label_category', [], $supported_locale),
                                    // 'locale' => $supported_locale,
                                    'value' => $post->category->translateOrDefault($supported_locale)->name,
                                    'link' =>route('algo.categories.show', $post->category->id)
                                ])

                                @if ($post->tags->count() > 0)
                                    @field([
                                        'label' => trans('algo::algo.label_tags', [], $supported_locale),
                                        // 'locale' => $supported_locale,
                                        'value' => implode(' ', $post->tags->map(function($tag) use ($supported_locale) {
                                                return "<a href='" .route('algo.tags.show', $tag->id) . "'><span class='badge badge-light'>#{$tag->translateOrDefault($supported_locale)->name}</span></a>";
                                            })->toArray())
                                    ])
                                @endif
                            @endtabpanel
                        @endforeach
                    </div>

                    @if (!empty($post->video_link))
                        @field([
                            'label' => 'YouTube Video Link',
                            'value' => $post->getYouTubeEmbedLink(),
                            'embed' => true
                        ])
                    @endif

                    @field([
                        'label' => trans('algo::algo.label_author', [], $supported_locale),
                        'value' => $post->author->name,
                        'link' =>route('algo.users.show', $post->author->id)
                    ])

                    @if ($post->isPublished())
                        @field([
                            'label' => trans('algo::algo.label_published_at', [], $supported_locale),
                            'value' => $post->published_at->format('d.m.Y H:i')
                        ])
                    @endif

                    @field([
                        'label' => trans('algo::algo.created_at'),
                        'value' => $post->created_at->format('d.m.Y H:i')
                    ])

                    @if (!is_null($post->updated_at))
                        @field([
                            'label' => trans('algo::algo.updated_at'),
                            'value' => $post->updated_at->format('d.m.Y H:i')
                        ])
                    @endif

                    <div class="mt-4">
                        <a href="{{ route('algo.posts.edit', $post->id) }}" class="btn btn-sm btn-outline-primary">@lang('algo::algo.edit')</a>
                        <a href="{{ route('algo.posts.destroy', $post->id) }}" data-id="{{ $post->id }}" data-confirm="{{ trans("algo::algo.posts.confirm_delete") }}" class="btn btn-sm btn-outline-danger js-confirm-delete">@lang('algo::algo.delete')</a>
                        <form style="display: none;" id="delete-form-{{ $post->id }}" method="POST" action="{{ route('algo.posts.destroy', $post->id) }}">
                            @csrf
                            @method('DELETE')
                        </form>
                    </div>

                </div>
            </div>
        </div>
    </div>
</div>
@endsection
