<?php

namespace Laravelista\Algo;

use Illuminate\Support\Str;
use Laravelista\Algo\Helpers\Slug;
use Laravelista\Algo\Models\Post;
use Laravelista\Algo\Models\Traits\Imageable;
use Laravelista\Picasso\Facade as Picasso;

/**
 * Attach this trait to the defined User model.
 */
trait Author
{
    use Imageable;

    /**
     * It returns the gravatar for the user in defined size.
     */
    public function getGravatar(int $size = 200): string
    {
        $hash = md5($this->email);

        return "https://www.gravatar.com/avatar/{$hash}?s={$size}";
    }

    /**
     * It returns the user image or fallbacks to gravatar.
     */
    public function getImage(string $dimension, int $size = 200): string
    {
        if ($this->hasImage()) {
            return Picasso::get($this->image, $dimension);
        } else {
            return $this->getGravatar(size: $size);
        }
    }

    /**
     * It returns the slug from database or a fallback;
     * which creates a slug from users name.
     */
    public function getSlug()
    {
        return (new Slug(new Str()))->get(
            input: $this->slug,
            fallback: $this->name
        );
    }

    /**
     * It returns all posts for the user.
     */
    public function posts()
    {
        return $this->hasMany(Post::class, 'author_id');
    }
}
