<?php

namespace Laravelista\Algo\Controllers;

use Illuminate\Contracts\Routing\ResponseFactory;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Lang;
use Illuminate\Validation\Rule;
use Laravelista\Algo\Helpers\Slug;
use Laravelista\Algo\Helpers\ValidateLocale;
use Laravelista\Algo\Models\Category;

class CategoryTranslationController extends Controller
{
    public function __construct(
        protected ResponseFactory $response,
        protected ValidateLocale $validateLocale
    ) {
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Category $category, string $locale): Response
    {
        $this->validateLocale->validate($locale);

        return $this->response->view(
            view: 'algo::categories.translations',
            data: [
                'category' => $category,
                'locale' => $locale
            ]
        );
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Category $category, string $locale, Slug $slug): RedirectResponse
    {
        $this->validateLocale->validate($locale);

        $validatedData = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'slug' => [
                'nullable', 'string', 'max:255',
                Rule::unique('category_translations')
                    ->ignore($category->getAttribute(key: 'id'), 'category_id')
                    ->where('locale', $locale)
            ],
            'description' => ['nullable', 'string'],
        ]);

        $category->translateOrNew($locale)->name = $validatedData['name'];
        $category->translateOrNew($locale)->slug = $slug->get(
            input: $validatedData['slug'] ?? null,
            fallback: $validatedData['name']
        );
        $category->translateOrNew($locale)->description = $validatedData['description'] ?? null;
        $category->save();

        return $this->response
            ->redirectToRoute(
                route: 'algo.categories.translations.edit',
                parameters: [
                    $category->getAttribute(key: 'id'), $locale
                ]
            )
            ->with('status', Lang::get('algo::algo.controllers.category_translation.translated'));
    }
}
