<?php

namespace Laravelista\Algo\Controllers;

use Illuminate\Contracts\Routing\ResponseFactory;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Lang;
use Illuminate\Validation\Rule;
use Laravelista\Algo\Helpers\Slug;
use Laravelista\Algo\Helpers\ValidateLocale;
use Laravelista\Algo\Models\Post;

class PostTranslationController extends Controller
{
    public function __construct(
        protected ResponseFactory $response,
        protected ValidateLocale $validateLocale
    ) {
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Post $post, string $locale): Response
    {
        $this->validateLocale->validate($locale);

        return $this->response->view(
            view: 'algo::posts.translations',
            data: [
                'post' => $post,
                'locale' => $locale
            ]
        );
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Post $post, $locale, Slug $slug): RedirectResponse
    {
        $this->validateLocale->validate($locale);

        $validatedData = $request->validate([
            'title' => ['required', 'string', 'max:255'],
            'intro' => ['nullable', 'string', 'max:255'],
            'content' => ['required', 'string'],
            'slug' => [
                'nullable', 'string', 'max:255',
                Rule::unique('post_translations')
                    ->ignore($post->getAttribute('id'), 'post_id')
                    ->where('locale', $locale)
            ],
        ]);

        $post->translateOrNew($locale)->title = $validatedData['title'];
        $post->translateOrNew($locale)->intro = $validatedData['intro'] ?? null;
        $post->translateOrNew($locale)->content = $validatedData['content'];
        $post->translateOrNew($locale)->slug = $slug->get($validatedData['slug'] ?? null, $validatedData['title']);
        $post->save();

        return $this->response
            ->redirectToRoute(
                route: 'algo.posts.translations.edit',
                parameters: [
                    $post->getAttribute('id'), $locale
                ]
            )
            ->with('status', Lang::get('algo::algo.controllers.post_translation.translated'));
    }
}
